@@ -242,15 +242,11 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
             logger.exception(f"[{request.url}] Error while downloading request")
         else:
             logger.info(f"[{request.url}] Return result")
+            return result
+        finally:
+            logger.info(f"[{request.url}] Finally")
             if not page.is_closed():
                 await page.close()
-            return result
-        # finally:
-        #     logger.info(f"[{request.url}] Finally")
-        #     if page is not None and not page.is_closed():
-        #         await page.close()
-        #     self.stats.inc_value("playwright/page_count/closed")
-        #     self.context_semaphores['default'].release()
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
